==> bbctrl-1.0.4-rc12.tar.bz2: bbctrl-1.0.4/src/py/lcd/splash.py <==
#!/usr/bin/env python3

################################################################################
#                                                                              #
#                 This file is part of the Buildbotics firmware.               #
#                                                                              #
#        Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.      #
#                                                                              #
#         This Source describes Open Hardware and is licensed under the        #
#                                 CERN-OHL-S v2.                               #
#                                                                              #
#         You may redistribute and modify this Source and make products        #
#    using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).  #
#           This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED          #
#    WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS  #
#     FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable    #
#                                  conditions.                                 #
#                                                                              #
#                Source location: https://github.com/buildbotics               #
#                                                                              #
#      As per CERN-OHL-S v2 section 4, should You produce hardware based on    #
#    these sources, You must maintain the Source Location clearly visible on   #
#    the external case of the CNC Controller or other product you make using   #
#                                  this Source.                                #
#                                                                              #
#                For more information, email info@buildbotics.com              #
#                                                                              #
################################################################################

import lcd

if __name__ == "__main__":
    screen = lcd.LCD(1, 0x27)

    screen.clear()
    screen.display(0, 'Buildbotics', lcd.JUSTIFY_CENTER)
    screen.display(1, 'Controller', lcd.JUSTIFY_CENTER)
    screen.display(3, 'Booting...', lcd.JUSTIFY_CENTER)

==> bbctrl-2.0.0-rc2.tar.bz2: bbctrl-2.0.0/src/py/lcd/splash.py <==
#!/usr/bin/env python3

################################################################################
#                                                                              #
#                 This file is part of the Buildbotics firmware.               #
#                                                                              #
#        Copyright (c) 2015 - 2021, Buildbotics LLC, All rights reserved.      #
#                                                                              #
#         This Source describes Open Hardware and is licensed under the        #
#                                 CERN-OHL-S v2.                               #
#                                                                              #
#         You may redistribute and modify this Source and make products        #
#    using it under the terms of the CERN-OHL-S v2 (https:/cern.ch/cern-ohl).  #
#           This Source is distributed WITHOUT ANY EXPRESS OR IMPLIED          #
#    WARRANTY, INCLUDING OF MERCHANTABILITY, SATISFACTORY QUALITY AND FITNESS  #
#     FOR A PARTICULAR PURPOSE. Please see the CERN-OHL-S v2 for applicable    #
#                                  conditions.                                 #
#                                                                              #
#                Source location: https://github.com/buildbotics               #
#                                                                              #
#      As per CERN-OHL-S v2 section 4, should You produce hardware based on    #
#    these sources, You must maintain the Source Location clearly visible on   #
#    the external case of the CNC Controller or other product you make using   #
#                                  this Source.                                #
#                                                                              #
#                For more information, email info@buildbotics.com              #
#                                                                              #
################################################################################

try:
    import smbus
except:
    import smbus2 as smbus

import lcd


if __name__ == "__main__":
    bus    = 1
    addr   = 0x27
    i2c    = smbus.SMBus(bus)
    screen = lcd.LCD(lambda byte: i2c.write_byte(addr, byte))

    screen.clear()
    screen.display(0, 'Buildbotics', lcd.JUSTIFY_CENTER)
    screen.display(1, 'Controller',  lcd.JUSTIFY_CENTER)
    screen.display(3, 'Booting...',  lcd.JUSTIFY_CENTER)
